// Fichier Strategie.H
/////////////////////////////////////////////////////////

/********************************************************
 *                                                      *
 *                En-tte de la librairie           	*
 *					strategie							*
 *                                                      *
 * .Date de cration : 29/12/07                         *
 * .Auteur : Philippe Lucidarme                         *       
 *                                                      *
 * .Descriptions :                                      *
 *      - code des fonctions pour la straegie   		*
 *                                                      *
 *                                                      *
 * .Remarques :                                         *
 *                                                      *
 ********************************************************/
#ifndef __STRATEGIE_H__
#define __STRATEGIE_H__


#include "lcd.h"
#include "StartUp.h"
#include "JoyStick.h"
#include "Propulsion.h"
#include "rouleaux.h"
#include "IO.h"
#include "I2C_Master.h"
#include "barillet.h"
#include "Horloge.h"
#include "strategie_bleue.h"
#include "led.h"
#include "Telemetres.h"
#include "serial.h"
#include "canon.h"
#include "Tourelle.h"
#include "Recal.h"
#include "Distributeur.h"





#define		VIT_EVIT					50				// Vitesse lors de la manoeuvre d'vitement d'obstacle

#define		Y_DISTRI_BLANC_BLEU			750				// Position en Y du barillet blanc


#define		VIT_LENTE					80				// Vitesse de dplacement lente
#define		VIT_RAPIDE					100				// Vitesse de dplacement rapide





#define		Y_CONTENEUR				1700				// Position en Y quand on va au conteneur

#define		X_INTER_DISTRIBUTEUR	500					// Point de passage intermdiare quand on passe ct distributeur	
#define		Y_INTER_DISTRIBUTEUR	800				
		
#define		X_INTER_CONTENEUR		1900				// Point de passage intermdiare quand on passe ct conteneur	
#define		Y_INTER_CONTENEUR		1600				


#define 	DELTA_ANGLE				-0.3				// Dcalage vers le sens de la pente quand on dpose

														// Condition de changement de direction
#define		CONDITION_CHANGE_DIR	X_Propulsion()<1500 || Y_Propulsion()>800	

#define		X_CONTENEUR_SECOURS		400					// Position de docking au conteneur de secours






// --------------------------------------------------------------------------
/* Recalage ct bleue
 * Le robot se place sur son aire de dpart et se recalle en X puis en Y 
 * On suppose que le robot se trouve approximativement en 2650,350 
 * Arguments : 
 *  En_X pour se recaler en X
 *	En_Y pour se recaler en Y
 * 
 * Paramtre retourn : 
 *   Aucun
*/
void Recal_Cote_Bleu (unsigned char En_X,unsigned char En_Y);




// --------------------------------------------------------------------------
/* Retourne du ct bleu align sur les deux distributeurs
 * Normalement on vite le robot adverse. Au bout de trois fois, 
 * on passe en force
 * Arguments : 
 *   Aucun
 * 
 * Paramtre retourn : 
 *   Aucun
*/
unsigned char Goto_Cote_Bleu (void);





// --------------------------------------------------------------------------
/* Retourne du ct bleu align sur les deux distributeurs en marche arrire
 * Normalement on vite le robot adverse. Au bout de trois fois, 
 * on passe en force
 * Arguments : 
 *   Aucun
 * 
 * Paramtre retourn : 
 *   Aucun
*/
unsigned char Goto_Cote_Bleu_Arriere (void);


// --------------------------------------------------------------------------
/* Va se placer contre le conteneur standard en marche arrire.
 * Normalement on vite le robot adverse. Au bout de trois fois, 
 * on passe en force
 * Arguments : 
 *  - La position en X du point de dpose 
 * 
 * Paramtre retourn : 
 *   Aucun
*/
unsigned char Goto_Conteneur (int X);





// --------------------------------------------------------------------------
/* Avance et oriente lgrement le robot dans le sens de la pente
 * puis depose les balles
 * Arguments : 
 * 	- la couleur que l'on va jouer durant ce match
 * 
 * Paramtre retourn : 
 *   0 : tout s'est bien pass,
 * 	-1 : Une collision s'est produite sur le BUS IC ou l'esclave n'a pas renvoy d'acknoledgment aprs l'adresse
*/
void Depose_Balles (char Couleur);




// --------------------------------------------------------------------------
/* Routine qui va cherche N balles au distributeur bleu
 * Le robot doit absoluement se trouver juste en face du distributeur
 *
 * Arguments : 
 * 	Le nombre de balles bleues dsir dans le barillet
 * 
 * Paramtre retourn : 
 *  aucun
*/

void Distributeur_Bleu (char NbBalles);



// --------------------------------------------------------------------------
/* Routine qui va cherche N balles au distributeur blanc du ct bleu
 * Le robot doit absoluement se trouver juste en face du distributeur
 *
 * Arguments : 
 * 	Le nombre de balles blanches dsir dans le robot
 *  Le delta Y duquel il faut dcaller le robot pour tomber en face du distributeur
 * 
 * Paramtre retourn : 
 *  aucun
*/

void Distributeur_Blanc_Bleu (char NbBalles, int Triche);





// --------------------------------------------------------------------------
/* Routine d'vitement du robot adverse :
 * On tourne le robot pour avoir l'adversaire soit sur un ct gauche ou droit  90
 * Puis on regarde s'il est devant ou derrire et on avance ou recule en consquence 
 * La distance parcouru est dpendante de la nouvelle position du robot
 *
 * Arguments : 
 * 	aucun
 * 
 * Paramtre retourn : 
 *  aucun
*/
void Evite_Robot_Adverse(void);




// --------------------------------------------------------------------------
/* Routine qui va cherche N balles au distributeur blanc du ct rouge
 * Le robot doit absoluement se trouver juste en face du distributeur
 *
 * Arguments : 
 * 	Le nombre de balles blanches dsir dans le robot
 *  Le delta Y duquel il faut dcaller le robot pour tomber en face du distributeur
 * 
 * Paramtre retourn : 
 *  aucun
*/

unsigned char Distributeur_Blanc_Rouge (char NbBalles, int Triche);

//-----------------------------------------------------------------------
/* Le robot se recal sur un bord avec les switchs
 * Le robot doit tre prs d'un bord
 *
 * Arguments : 
 * 	aucun
 * 
 * Paramtre retourn : 
 *  0 : le recallage est un chec
 *  1 : le recallage est russit
*/
unsigned char Recal_Avant(void);



//-----------------------------------------------------------------------
/* Le robot se recal sur un bord avec les switchs
 * Le robot doit tre prs d'un bord
 *
 * Arguments : 
 * 	aucun
 * 
 * Paramtre retourn : 
 *  0 : le recallage est un chec
 *  1 : le recallage est russit
*/
unsigned char Recal_Arriere(void);



//-----------------------------------------------------------------------
/* Le robot se place en dfense de notre ct en protgeant les balles
 *
 * Arguments : 
 * 	aucun
 * 
 * Paramtre retourn : 
 *	 aucun
 */
void Defense_Bleue(void);



#endif
